/**
Alexandru Petrescu
O(N^2 * K * logK)
featuring: heapuri de mana
**/

#include <cstdio>
#include <cctype>
#include <cstring>
#include <algorithm>

FILE *fin = fopen("cetate.in", "r"), *fout = fopen("cetate.out", "w");

#define BUF_SIZE 1 << 17

int pos = BUF_SIZE;
char buf[BUF_SIZE];

inline char nextch() {
    if (pos == BUF_SIZE) fread(buf, BUF_SIZE, 1, fin), pos = 0;
    return buf[pos++];
}

inline int read() {
    char ch = nextch();
    while (ch != '-' && !isdigit(ch)) ch = nextch();
    int s = 1;
    if (ch == '-') s = -1, ch = nextch();
    int x = ch - '0';
    while (isdigit(ch = nextch())) x = 10 * x + ch - '0';
    return s * x;
}

#define LIM 501

int n, heap[LIM], poz[LIM];
long long d[LIM], s[LIM][LIM];

inline void mySwap(int &p, int q) {
    int aux = heap[p];
    heap[p] = heap[q];
    heap[q] = aux;
    poz[heap[p]] = p;
    poz[heap[q]] = q;
    p = q;
}

inline void urcare(int p) {
    if (p > n) return ;
    while (p > 1 && d[heap[p]] > d[heap[p / 2]]) mySwap(p, p / 2);
}

inline void coborare(int p) {
    int q;
    bool f = 1;
    while (f && (q = 2 * p) <= n) {
        q += (q < n && d[heap[q + 1]] > d[heap[q]]);
        if (d[heap[q]] > d[heap[p]]) mySwap(p, q);
        else f = 0;
    }
}

inline void baga(int p, long long val) {
    heap[++n] = p;
    d[p] = val;
    poz[p] = n;
    urcare(n);
}

inline void scoate(int p) {
    int u = poz[p];
    heap[u] = heap[n];
    poz[heap[n--]] = u;
    coborare(u);
    urcare(u);
}

int main() {
    int c = read();
    int nrlin = read();
    int nrcol = read();
    int k = read();

    if (c != 2)
        return 0;

    for (int i = 1; i <= nrlin; i++)
        for (int j = 1; j <= nrcol; j++)
            s[i][j] = read() + s[i - 1][j] + s[i][j - 1] - s[i - 1][j - 1];

    long long ans = s[1][1];
    int sol1 = 1, sol2 = 1, sol3 = 1, sol4 = 1;
    for (int i = 1; i <= nrlin; i++) {
        for (int l = i; l <= nrlin && l - i < k; l++) {
            n = 0;
            for (int j = nrcol; j > 0; j--) {
                baga(j, s[l][j] - s[i - 1][j]);
                if (j + k <= nrcol) scoate(j + k);
                long long val = d[heap[1]] - (s[l][j - 1] - s[i - 1][j - 1]);
                if (val > ans || (val == ans && i == sol1 && j < sol2)) sol1 = i, sol2 = sol4 = j, sol3 = l, ans = val;
            }
        }
    }

    while (s[sol3][sol4] - s[sol3][sol2 - 1] - s[sol1 - 1][sol4] + s[sol1 - 1][sol2 - 1] != ans)
        sol4++;

    fprintf(fout, "%lld\n%d %d %d %d\n", ans, sol1, sol2, sol3, sol4);

    fclose(fin);
    fclose(fout);
    return 0;
}
